to_mtx_bytes

Function to_mtx_bytes 

pub fn to_mtx_bytes(matrix: &CsMat<f64>) -> Result<Vec<u8>>
The complete Matrix Market text for one matrix, symmetric when the header round trips exactly and general otherwise.